## description

    hrepr(obj)

## obj

    {'functions': [<function hshort XXX>, <function Point.some_method XXX>, <function <lambda> XXX>], 'generators': [<generator object _gen XXX>], 'coroutines': [<coroutine object _coro XXX>, <async_generator object _corogen XXX>], 'classes': [<class 'tests.test_hrepr.Point'>, <class 'Exception'>, <class 'type'>], 'builtins': [<built-in function pow>, <built-in function print>, <built-in method append of list object XXX>], 'wrappers': [<method 'update' of 'dict' objects>, <slot wrapper '__str__' of 'object' objects>], 'methods': [<bound method Point.some_method of Point(x=1, y=2)>, <method-wrapper '__str__' of list object XXX>], 'modules': [<module 'dataclasses' XXX>], 'ellipsis': Ellipsis}

## result

{

functions | : | [ function hshort function some_method function <lambda> ]
generators | : | [ generator _gen ]
coroutines | : | [ coroutine _coro async_generator _corogen ]
classes | : | [ class Point class Exception metaclass type ]
builtins | : | [ builtin pow builtin print builtin <list>.append ]
wrappers | : | [ descriptor dict.update descriptor object.__str__ ]
methods | : | [ method <Point>.some_method method <list>.__str__ ]
modules | : | [ module dataclasses ]
ellipsis | : | <ellipsis>

}